'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _resolveMethod = require('./resolveMethod');

var _resolveMethod2 = _interopRequireDefault(_resolveMethod);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (_ref) {
    var t = _ref.types;

    var importMethod = undefined,
        lodashObjects = undefined,
        selectedMethods = undefined,
        specified = undefined;

    importMethod = function (methodName, file) {
        if (!selectedMethods[methodName]) {
            selectedMethods[methodName] = file.addImport((0, _resolveMethod2.default)(methodName), 'default', methodName);
        }

        return selectedMethods[methodName];
    };

    return {
        visitor: {
            CallExpression: function CallExpression(path) {
                var file = undefined,
                    name = undefined,
                    node = undefined;

                node = path.node;
                name = node.callee.name;
                file = path.hub.file;

                if (!t.isIdentifier(node.callee)) {
                    return;
                }

                // console.log('specified[name]', specified[name], 'name', name, 'specified', specified);

                if (specified[name]) {
                    node.callee = importMethod(specified[name], file);
                }

                if (lodashObjects[name]) {
                    throw new Error('lodash chaining syntax is not supported.');
                }

                // console.log('Hello!');
            },
            ImportDeclaration: function ImportDeclaration(path) {
                var node = undefined,
                    value = undefined;

                node = path.node;
                value = node.source.value;

                if (value !== 'lodash') {
                    return;
                }

                node.specifiers.forEach(function (specifier) {
                    if (t.isImportSpecifier(specifier)) {
                        specified[specifier.local.name] = specifier.imported.name;
                    } else {
                        lodashObjects[specifier.local.name] = true;
                    }
                });

                path.remove();
            },
            MemberExpression: function MemberExpression(path) {
                var file = undefined,
                    node = undefined;

                node = path.node;
                file = path.hub.file;

                if (!lodashObjects[node.object.name]) {
                    return;
                }

                if (node.property.name === 'chain') {
                    throw new Error('lodash chaining syntax is not supported.');
                }

                path.replaceWith(importMethod(node.property.name, file));
            },

            Program: {
                enter: function enter() {
                    lodashObjects = {};
                    specified = {};
                    selectedMethods = {};
                }
            }
        }
    };
};

module.exports = exports['default'];
//# sourceMappingURL=index.js.map
